@@ -153,6 +153,7 @@ def sync_detailed(
     page: Union[Unset, None, int] = UNSET,
     search: Union[Unset, None, str] = UNSET,
     size: Union[Unset, None, int] = UNSET,
+    httpx_client=None,
 ) -> Response[
     Union[
         PublicListDatabaseTableGalleryViewRowsResponse400,
@@ -210,7 +211,7 @@ def sync_detailed(
         size=size,
     )
 
-    response = httpx.request(
+    response = (httpx_client or httpx).request(
         verify=client.verify_ssl,
         **kwargs,
     )
